# Plugin Ionic-Capacitor Project Integration Guide

This guide will walk you through how to integrate the Pointr Ionic Cordova plugin to your Ionic Capacitor project.

## Prerequisites

PointrContent archives provided by the PMs should be placed under `cordova-plugin-pointr/contents` folder.

For each `PointrContent-<environment>.zip` file you need to add resource-file nodes to android and ios platforms inside cordova-plugin-pointr/plugin.xml file.

### Android

`<resource-file src="contents/PointrContent-qa.zip" target="assets/PointrContent-qa.zip" />`

### iOS

`<resource-file src="contents/PointrContent-qa.zip"/>`

> :warning: File names under src and target attributes must be the same. If you do not add this properly , Pointr SDK will not be able to find the appropriate content hence it will not start.

## Android

Before you begin the steps below, make sure you have downloaded the Cordova Pointr Plugin v8 from the documentation center.

Also, while executing the following commands from terminal, make sure the active directory is the directory of your Ionic capacitor project.

### Step 1: Add Android Platform to your Capacitor project

`> ionic capacitor add android`

### Step 2: Install the Pointr Cordova plugin

`> npm i <cordova-plugin-pointr path>`

### Step 3: Make sure that jetifier is installed and ready to use. This is required because Pointr Android SDK uses support libraries.

`> npm install jetifier`

`> npx jetify`

`> npx cap sync android`

`> ionic build`

### Step 4: Add custom repositories in android/build.gradle

This is the directory where the mentioned build.gradle resides

The following repositories should be added to allprojects/repositories section in the above file.

```gradle
jcenter()
mavenCentral()
maven {
    url "https://android.pointr.dev/artifactory/gradle-release-local"
    // For plugins and TileView
    credentials {
        username '<username>'
        password '<password>'
    }
    maven { url 'https://jitpack.io' }
}
```

### Step 5: Make sure your kotlin gradle plugin version is compatible

Go to the android/build.gradle file (same as step-4) and add the following line under buildscript.dependencies;

`> classpath "org.jetbrains.kotlin:kotlin-gradle-plugin:1.6.0"`

You are set ! After this you should open the android directory of your ionic project from Android Studio, and hit Run on a real device or emulator!


    In order to use the Pointr methods, you need to use the `initialize("<licenseKeyForEnvironment>", "<environment>", "<logLevel>")` method. If you do not initialize Pointr using this method, the other methods will not function.

    For advanced developers, if you like to bridge some more of the native methods of Pointr SDK to your ionic project, you can check the api reference page in our docs center, and add the new bridge methods to the Pointr Plugin taking the existing implementations as reference.

    Make sure that the PointrContent.zip for the selected environment is available.

### Troubleshooting

#### Module was compiled with an incompatible version of Kotlin. The binary version of its metadata is 1.6.0, expected version is 1.4.2.

##### Solution

Your project should use kotlin-gradle-plugin:1.6.0

The buildscript dependency classpath for kotlin gradle plugin should be:

`> classpath "org.jetbrains.kotlin:kotlin-gradle-plugin:1.6.0"`

This should be changed from your android/build.gradle file. Check Step 5 for more details.

#### I have changed the files on my Ionic project and build the platforms again, I am receiving errors.

##### Solution

Check the android/capacitor-cordova-android-plugins/build.gradle file, and make sure the following dependencies are included under dependencies, commented with SUB-PROJECT DEPENDENCIES START.

```gradle
// Pointr Dependencies START
implementation 'com.pointrlabs:pointr:8.0.0'
// required library to fix issue with arm64 emulators
implementation 'com.facebook.soloader:soloader:0.10.3'
// Pointr Dependencies END
```



    The facebook.soloader dependency is needed to run the SDK on arm64 emulators


#### I have changed some files in ionic project but they are not reflected in the app.

##### Solution

You need to run 'ionic cap build android' for the changes to be reflected on the application.

#### This version of the Android Support plugin for IntelliJ IDEA (or Android Studio) cannot open this project, please retry with version 2021.2.1 or newer.

##### Solution

You should upgrade your AS to the latest.


## iOS

To enable ios run time on your environment you can follow the instructions given on the link [https://capacitorjs.com/docs/ios](https://capacitorjs.com/docs/ios)

Two frameworks are needed before installing the plugin. The token to download the PointrKit will be provided by the responsible Project Manager.

1. [PointrKit.xcframework](https://pointrapps.blob.core.windows.net/sdk/ios/PointrKit/8.0.0/PointrKit.zip?se=2023-09-29&sp=r&spr=https&sv=2018-11-09&si=pointr&sr=c&sig=G/9icYaOyF9s0HAinF6HdJxBFVJxF6MXS96JRHgPF7A%3D)
2. [Mapbox.xcframework](https://github.com/maplibre/maplibre-gl-native/releases/download/ios-v5.12.1/Mapbox-5.12.1.zip)

Download and extract the frameworks from the links above. Put both libraries under cordova-plugin-pointr/libs folder.

Install the plugin using these commands:

```bash
npm i <path to cordova-plugin-pointr>
npx cap sync ios
ionic cap build ios
```

If it is not automatically launched, open ios/App/App.xcworkspace with Xcode. Manage application bundle identifier and signings.

Add necessary permissions related with location tracking into ios/App/Info.plist file

Below is the minimum permission requirement necessary for Pointr SDK to work.

```xml
<key>NSLocationWhenInUseUsageDescription</key>
<string>Pointr needs to know your location.</string>
```

You can find more detailed information about permissions from [/docs/8.x/Developer%20Portal/Pointr%20Mobile%20SDK/Information/Operating%20System%20Permissions/](/docs/8.x/Developer%20Portal/Pointr%20Mobile%20SDK/Information/Operating%20System%20Permissions/)

For more information about iOS configuration, you can check the capacitor official documentation [https://capacitorjs.com/docs/ios/configuration](https://capacitorjs.com/docs/ios/configuration)

### Troubleshooting

#### No architecture found for Maps_Pod

##### Solution

From XCode clean your project (XCode / Product / Clean Build Folder) and run again.


#### Application Crash while trying to render the map on iOS simulator with M1 Mac machine.

##### Solution

Run XCode in Rosetta mode.


#### I have changed some files in ionic project but they are not reflected in the app.

##### Solution

You need to run 'ionic cap build ios' for the changes to be reflected on the application.
